@@ -147,24 +147,6 @@ function hover_popup(data, map) {
 }
 
 
-// jQuery.fn.collagePopup = function () {
-//     var url, collage_id;
-//     url = $(this).closest("[data-url-lizard-map-collage-popup]").attr("data-url-lizard-map-collage-popup");
-//     collage_id = $(this).closest("[data-collage-id]").attr("data-collage-id");
-//     $.getJSON(
-//         url,
-//         { collage_id: collage_id },
-//         function (data) {
-//             show_popup(data);
-//             // Mark popup as being a collage popup
-//             $("#dialog-content div:first-child").data("is_collage_popup", true);
-
-//         }
-//     );
-
-// };
-
-
 /* Make workspaces sortable and droppable
 
 Needed: data attribute .data-url-lizard-map-workspace-item-reorder on
@@ -288,8 +270,11 @@ jQuery.fn.updateWorkspace = function () {
                 if ($("#map").length > 0) {
                     refreshLayers(); // from lizard_wms.js
                 }
-                // Is this enough? See also refreshMapActionsDivs in lizard_map
+                // Is this enough? See also refreshMapActionsDivs in
+                // lizard_map
 
+                // TODO: there refreshes are also used in lizard_map:
+                // replaceItems. See if we can bring it together.
                 updateWorkspaceAcceptableStatus();
 
                 setUpAnimationSlider();
@@ -394,6 +379,17 @@ jQuery.fn.lizardMapLink = function () {
 };
 
 
+/*
+Check if selector returns any elements
+
+Used like:
+$("#notAnElement").exists();
+*/
+jQuery.fn.exists = function () {
+    return this.length !== 0;
+}
+
+
 $(document).ready(function () {
     // Change "default" effect: reload graphs to fix layout.
     $.tools.tabs.addEffect(
