@@ -222,6 +222,17 @@ function dialogContent(content) {
     $("#dialog-content").html(content);
 }
 
+
+function dialogText(title, content) {
+    var html;
+    html = "<h1>" + title + "</h1>" +
+        "<p>" + content + "</p>";
+    dialogContent(html);
+    dialogSize("s");
+    dialogOverlay();
+}
+
+
 /* L3 pop up the dialog */
 function dialogOverlay() {
     var overlay;
@@ -244,26 +255,53 @@ function dialogClose() {
 }
 
 
-/* L3 dialog replace ids */
-function dialogReplaceTitles(new_content) {
-    var replace_titles, id, ids, div, title, i;
-    // Create array with ids to be replaced.
-    // There may be some empty strings in this list.
-    ids = $("#dialog").data("replace-titles").split(" ");
+/* Create array with ids to be replaced.
+ There may be some empty strings in this list. */
+function dialogReplaceItemIds() {
+    var ids;
+    ids = $("#dialog").data("replace-items").split(" ");
+    return ids;
+}
 
+
+/* L3 dialog replace ids with same items in new_content
+
+Also refreshes known elements after replacing specific ids.
+*/
+function replaceItems(ids, new_content) {
+    var replace_items, id, div, $replace_with, i, replaced_count,
+        refresh_map, refresh_animation_slider;
     // Place a div around everything to allow searching through the
     // root objects.
     div = $("<div/>").html(new_content);
 
+    refresh_map = false;
+    refresh_animation_slider = false;
+
     for (i in ids) {
         if (i !== undefined) {
             id = ids[i];
             if (id !== "") {
-                title = div.find("#" + id);
-                $("#" + id).attr("title", title.html());
+                $replace_with = div.find("#" + id);
+                // There should be only one.
+                $("#" + id).replaceWith($replace_with[0]);
+                if (id === 'date-range') {
+                    refresh_map = true;
+                    refresh_animation_slider = true;
+                }
             }
         }
     }
+
+    // Gui elements that are initialized after replacing items.
+    if (refresh_animation_slider) {
+        setUpAnimationSlider();
+    }
+    if (refresh_map) {
+        if ($("#map").exists()) {
+            refreshLayers(); // from lizard_wms.js
+        }
+    }
 }
 
 /* L3 Dialog size */
@@ -308,9 +346,9 @@ function dialogClick(event) {
     $("#dialog").data("submit-on-change", false);
     // All ids that have to be replaced in the original page. Space
     // separated.
-    $("#dialog").data("replace-titles", "");  // Reset
+    $("#dialog").data("replace-items", "");  // Reset
     $("#dialog").data(
-        "replace-titles", $(event.target).attr("data-replace-titles"));
+        "replace-items", $(event.target).attr("data-replace-items"));
     dialogSize($(event.target).attr("data-size"));
     return false;
 }
@@ -318,7 +356,7 @@ function dialogClick(event) {
 function helpDialogClick(event) {
     var url, overlay, size, msg;
     event.preventDefault();
-    
+
     $('a.ajax-help-dialog').each(function(index) {
         url = $(this).attr("href");
         $.get(url)
@@ -335,9 +373,9 @@ function helpDialogClick(event) {
     });
 }
 
-/* L3 Onchange on dialog: only on ajax-dialog-onchange */
+/* L3 Onchange on dialog: only on ajax-dialog-onchange  */
 function dialogOnChange(event) {
-    var $form;
+    var $form, ids;
     // console.log("dialog onchange");
     event.preventDefault();
     if ($("#dialog").data("submit-on-change")) {
@@ -355,9 +393,11 @@ function dialogOnChange(event) {
                         ".dialog-box");
                     // Bad request: wrong input
                     // Or 200, or else... all the same
-                    dialogReplaceTitles(context.responseText);
+                    ids = dialogReplaceItemIds();
+                    replaceItems(ids, context.responseText);
                     dialogContent(div);
                     dialogOverlay();
+
                     return false;
                 });
     }
@@ -370,7 +410,7 @@ function dialogSetupChange(event) {
 
 /* L3 Pressing submit in dialog box */
 function dialogSubmit(event, afterSubmit) {
-    var $form;
+    var $form, ids;
     event.preventDefault();
     $form = $(event.target).parents("form");
     // Strange: everything goes to .error
@@ -385,16 +425,22 @@ function dialogSubmit(event, afterSubmit) {
                 dialogContent(div);
                 dialogOverlay();
             } else if (context.status === 200) {
-                dialogReplaceTitles(context.responseText);
+                ids = dialogReplaceItemIds();
+                replaceItems(ids, context.responseText);
                 if ($("#dialog").data("submit-on-change")) {
                     // Close immediately, because the contents don't change.
-                    dialogClose();
+                    if (afterSubmit === undefined) {
+                        dialogClose();
+                    } else {
+                        afterSubmit(context);
+                    }
                 } else {
                     // Show success message, then close.
                     dialogContent(div);
                     dialogOverlay();
-                    dialogCloseDelay();
-                    if (afterSubmit !== undefined) {
+                    if (afterSubmit === undefined) {
+                        dialogCloseDelay();
+                    } else {
                         afterSubmit(context);
                     }
                 }
@@ -415,6 +461,7 @@ function dialogSubmit(event, afterSubmit) {
     return false;
 }
 
+
 function updateWorkspaceAfterSubmit(event) {
     return dialogSubmit(event, function (context) {
         return $(".workspace").updateWorkspace();
@@ -423,6 +470,8 @@ function updateWorkspaceAfterSubmit(event) {
 
 function reloadScreenAfterSubmit(event) {
     return dialogSubmit(event, function (context) {
+        dialogText("Herladen pagina",
+                   "De pagina wordt opnieuw geladen.");
         window.location.reload();
     });
 }
@@ -432,7 +481,7 @@ function reloadScreenAfterSubmit(event) {
 - Define an a href with class "ajax-dialog" or "ajax-dialog-onchange"
 - Optionally add attributes:
   - data-reload-after-submit="true": reloads the page after successful submit
-  - data-replace-titles="title_id1 title_id2": replaces given tag ids
+  - data-replace-items="title_id1 title_id2": replaces given tag ids
     after submit (or onchange).
 
 The actions are as follows:
@@ -450,8 +499,10 @@ function setUpDialogs() {
     $("#dialog input:submit:not(.alternative-submit)").live(
         "click", dialogSubmit);
     // Handle ajax-dialog-onchange, which submit on changes.
-    $("#dialog form input").live("change", dialogOnChange);
-    $("#dialog form select").live("change", dialogOnChange);
+    $("#dialog form input").live(
+        "change", dialogOnChange);
+    $("#dialog form select").live(
+        "change", dialogOnChange);
 
     // TODO: split this part. It is for specific lizard-map workspace stuff.
     // For workspace changes: live our own handler
@@ -494,11 +545,8 @@ function actionPostClick(event, preAction, postAction, parameters) {
             if ($(event.target).hasClass("reload-after-action")) {
                 // TODO: De-activate possible actions.
                 // Show dialog.
-                html = "<h1>Herladen pagina</h1>" +
-                    "<p>De pagina wordt opnieuw geladen.</p>";
-                dialogContent(html);
-                dialogSize("s");
-                dialogOverlay();
+                dialogText("Herladen pagina",
+                           "De pagina wordt opnieuw geladen.");
                 location.reload();
             }
         })
@@ -618,12 +666,8 @@ function eraseDialogContentsOnClose() {
 
 /* L3 popup with "niets gevonden" */
 function nothingFoundPopup() {
-    var html;
-    html = "<h1>Niets gevonden</h1>" +
-        "<p>Er is niets rond deze locatie gevonden</p>";
-    dialogContent(html);
-    dialogSize("s");
-    dialogOverlay();
+    dialogText("Niets gevonden",
+               "Er is niets rond deze locatie gevonden.");
     dialogCloseDelay();
 }
 
@@ -868,6 +912,43 @@ function setupTableToggle() {
 }
 
 
+function setUpDataFromUrl() {
+    // A div with class "data-from-url" will fetch data from attribute
+    // data-url and paste the contents in the div. The reason is that
+    // the calculation time for some objects can be long.
+    var $div;
+    $div = $("div.data-from-url");
+    $div.each(function () {
+        var url;
+        url = $(this).attr("data-url");
+        if (url !== undefined) {
+            // Put in progress animation
+            $(this).html(
+                '<img src="/static_media/lizard_ui/ajax-loader.gif" />');
+            // Load actual data.
+            $(this).load(url + " .dialog-box");
+        }
+    });
+}
+
+
+function setUpCollageEditor() {
+    // Set restrict_to_month on enabled or disabled
+    $("select#id_aggregation_period").live("change", function (event) {
+        // 4 is MONTH
+        console.log(this.value);
+        if (this.value === "4") {
+            $("select#id_restrict_to_month").removeAttr("disabled");
+        } else {
+            $("select#id_restrict_to_month").attr("disabled", "True");
+            $("select#id_restrict_to_month").each(function () {
+                this.value = "0";
+            });
+        }
+    });
+}
+
+
 // Initialize all workspace actions.
 $(document).ready(function () {
     // Touched/new for L3
@@ -875,6 +956,8 @@ $(document).ready(function () {
     setUpDialogs();
     eraseDialogContentsOnClose();
     setUpActions();
+    setUpDataFromUrl();
+    setUpCollageEditor();
 
     // Untouched
     setUpWorkspaceButtons();
