@@ -2,6 +2,7 @@ import StringIO
 import datetime
 
 from django.conf import settings
+from django.db import transaction
 from django.db.models import Max
 from django.http import HttpResponse
 from django.http import HttpResponseBadRequest
@@ -31,6 +32,7 @@ from lizard_map.animation import AnimationSettings
 from lizard_map.animation import slider_layout_extra
 from lizard_map.coordinates import DEFAULT_OSM_LAYER_URL
 from lizard_map.dateperiods import ALL
+from lizard_map.dateperiods import MONTH
 from lizard_map.daterange import compute_and_store_start_end
 from lizard_map.daterange import current_period
 from lizard_map.daterange import current_start_end_dates
@@ -89,12 +91,13 @@ class WorkspaceMixin(object):
         pass
 
     def animation_slider(self):
-        """Add animation slider? Default: none."""
-        if not hasattr(self, '_animation_slider'):
-            self._animation_slider = None  # default
-            if self.workspace().is_animatable:
-                self._animation_slider = AnimationSettings(self.request).info()
-        return self._animation_slider
+        """Add animation slider? Default: none. Calculate each time,
+        because the datetime settings could be changed in the
+        meanwhile."""
+        animation_slider = None
+        if self.workspace().is_animatable:
+            animation_slider = AnimationSettings(self.request).info()
+        return animation_slider
 
     def javascript_hover_handler(self):
         if not hasattr(self, '_javascript_hover_handler'):
@@ -405,24 +408,37 @@ class WorkspaceLoadView(ActionDialogView):
         workspace_edit.load_from_storage(workspace_storage)
 
 
-class DateRangeView(DateRangeMixin, ActionDialogView):
+class DateRangeView(DateRangeMixin, WorkspaceEditMixin, ActionDialogView):
     template_name = 'lizard_map/box_daterange.html'
     template_name_success = template_name
     form_class = DateRangeForm  # Define your form
 
+    reload_screen_after = False  # Default.
+
     def form_valid_action(self, form):
         """
         Update date range
         """
         logger.debug("Updating date range...")
         date_range = form.cleaned_data
-
         compute_and_store_start_end(self.request.session, date_range)
 
+    def get(self, request, *args, **kwargs):
+        self.reload_screen_after = request.GET.__contains__(
+            'reload_screen_after')
+        return super(DateRangeView, self).get(request, *args, **kwargs)
+
+    def post(self, request, *args, **kwargs):
+        self.reload_screen_after = request.GET.__contains__(
+            'reload_screen_after')
+        return super(DateRangeView, self).post(request, *args, **kwargs)
+
 
 class CollageItemEditorView(ActionDialogView):
     """
     Popup per collage item for adjustments in the graph.
+
+    TODO: make prettier. Split global settings and per collage-item settings.
     """
     template_name = 'lizard_map/box_collage_item_editor.html'
     template_name_success = 'lizard_map/box_collage_item_editor_success.html'
@@ -442,40 +458,87 @@ class CollageItemEditorView(ActionDialogView):
         return super(CollageItemEditorView, self).post(
             request, *args, **kwargs)
 
+    @transaction.commit_on_success
     def form_valid_action(self, form):
         """
-        Change collage-item accordingly
+        Change collage-item(s) accordingly
+
+        This is a little tricky: some fields are for the graph itself,
+        like title or y_min. Since the graph is used for multiple
+        collage-items, all those items are updated.
+
+        TODO: unit test.
+        TODO: unit test.
+        TODO: unit test.
         """
-        reserved = {'boundary_value': None,
-                    'percentile_value': None,
-                    'aggregation_period': None}
+
+        # Fields that must be applied to all group items
+        group_fields = {'title': None,
+                        'y_min': None,
+                        'y_max': None,
+                        'x_label': None,
+                        'y_label': None,
+                        'aggregation_period': None,
+                        'restrict_to_month': None}
 
         data = form.cleaned_data
+        # The collage item being edited.
         collage_item = CollageEditItem.objects.get(pk=self.collage_item_id)
-        identifier = collage_item.identifier
-        new_layout = identifier.get('layout', {})
 
-        # Reserved keywords
-        collage_item.boundary_value = data['boundary_value']
-        collage_item.percentile_value = data['percentile_value']
-        collage_item.aggregation_period = data.get('aggregation_period', ALL)
+        # Select group to update the parameters.
+        # Note: we also update invisible items
+        grouped_collage_items, collage_item_group = group_collage_items(
+            CollageEditItem.objects.all())
 
-        # Non reserved keywords
-        for k, v in data.items():
-            if k not in reserved:
-                # Everything resulting in True must be saved
-                # 0.0 must be saved
-                # u'' must be deleted
-                # False must be deleted
-                if v or isinstance(v, float):
-                    new_layout[k] = v
-                else:
-                    if k in new_layout:
-                        del new_layout[k]
+        grouping_hint = collage_item_group[collage_item.id]
+        collage_items = grouped_collage_items[grouping_hint]
 
-        identifier['layout'] = new_layout
-        collage_item.identifier = identifier
-        collage_item.save()
+        # Loop all collage_items in group
+        for single_collage_item in collage_items:
+            # Model field for every collage item.
+            single_collage_item.aggregation_period = data.get(
+                'aggregation_period', ALL)
+
+            identifier = single_collage_item.identifier
+            new_layout = identifier.get('layout', {})
+
+            # We have two instances of collage_item, only editing (and
+            # saving) the one in the group list.
+            if single_collage_item.id == collage_item.id:
+                single_collage_item.boundary_value = data['boundary_value']
+                single_collage_item.percentile_value = data['percentile_value']
+
+            # Layout properties
+            for k, v in data.items():
+                # Check per field if it is a group field.
+                if (single_collage_item.id == collage_item.id or
+                    k in group_fields):
+
+                    # Everything resulting in True must be saved
+                    # 0.0 must be saved
+                    # u'' must be deleted
+                    # False must be deleted
+                    if v or isinstance(v, float):
+                        new_layout[k] = v
+                    else:
+                        if k in new_layout:
+                            del new_layout[k]
+
+            # Restrict to month option which is currently used in NHI only.
+            if 'aggregation_period' in new_layout:
+                if int(new_layout['aggregation_period']) != MONTH:
+                    # Should not be there, but you never know.
+                    if 'restrict_to_month' in new_layout:
+                        del new_layout['restrict_to_month']
+            if ('restrict_to_month' in new_layout and
+                (new_layout['restrict_to_month'] == '0' or
+                new_layout['restrict_to_month'] is None)):
+
+                del new_layout['restrict_to_month']
+
+            identifier['layout'] = new_layout
+            single_collage_item.identifier = identifier
+            single_collage_item.save()
 
 
 # L3
@@ -621,124 +684,6 @@ def workspace_item_delete(request, workspace_edit=None, object_id=None):
 #     return HttpResponse(json.dumps(extent_converted))
 
 
-# # TODO: update to L3
-# @never_cache
-# def snippet_group_graph_edit(request, snippet_group_id):
-#     """Edits snippet_group properties using post.
-#     """
-#     post = request.POST
-#     title = post.get('title', None)
-#     x_label = post.get('x_label', None)
-#     y_label = post.get('y_label', None)
-#     y_min = post.get('y_min', None)
-#     y_max = post.get('y_max', None)
-#     boundary_value = post.get('boundary_value', None)
-#     percentile_value = post.get('percentile_value', None)
-#     aggregation_period = post.get('aggregation_period', None)
-#     restrict_to_month = post.get('restrict_to_month', None)
-#     if restrict_to_month is not None:
-#         try:
-#             restrict_to_month = int(restrict_to_month)
-#             assert restrict_to_month > 0
-#             assert restrict_to_month < 13
-#         except ValueError:
-#             restrict_to_month = None
-
-#     snippet_group = WorkspaceCollageSnippetGroup.objects.get(
-#         pk=snippet_group_id)
-#     if title is not None:
-#         # Empty string is also good! it will force default title.
-#         snippet_group.layout_title = title
-#     if x_label is not None:
-#         snippet_group.layout_x_label = x_label
-#     if y_label is not None:
-#         snippet_group.layout_y_label = y_label
-#     snippet_group.restrict_to_month = restrict_to_month
-#     if aggregation_period is not None:
-#         snippet_group.aggregation_period = int(aggregation_period)
-#     try:
-#         snippet_group.layout_y_min = float(y_min)
-#     except (ValueError, TypeError):
-#         snippet_group.layout_y_min = None
-#     try:
-#         snippet_group.layout_y_max = float(y_max)
-#     except (ValueError, TypeError):
-#         snippet_group.layout_y_max = None
-#     try:
-#         snippet_group.boundary_value = float(boundary_value)
-#     except (ValueError, TypeError):
-#         snippet_group.boundary_value = None
-#     try:
-#         snippet_group.percentile_value = float(percentile_value)
-#     except (ValueError, TypeError):
-#         snippet_group.percentile_value = None
-#     snippet_group.save()
-#     return HttpResponse('')
-
-
-# # TODO: update to L3
-# @never_cache
-# def snippet_group_image(request, snippet_group_id, legend=True):
-#     """Draws a single image for the snippet_group. There MUST be at
-#     least 1 snippet in the group."""
-
-#     snippet_group = WorkspaceCollageSnippetGroup.objects.get(
-#         pk=snippet_group_id)
-#     snippets = snippet_group.snippets.filter(visible=True)
-#     identifiers = [snippet.identifier for snippet in snippets]
-
-#     # Add aggregation_period to each identifier
-#     for identifier in identifiers:
-#         if not 'layout' in identifier:
-#             identifier['layout'] = {}
-#         identifier['layout'][
-#             'aggregation_period'] = snippet_group.aggregation_period
-
-#     # Add legend option ('layout' is always present).
-#     if legend:
-#         for identifier in identifiers:
-#             identifier['layout']['legend'] = True
-
-#     # Get width and height.
-#     width = request.GET.get('width')
-#     height = request.GET.get('height')
-#     if width:
-#         width = int(width)
-#     else:
-#         # We want None, not u''.
-#         width = None
-#     if height:
-#         height = int(height)
-#     else:
-#         # We want None, not u''.
-#         height = None
-
-#     using_workspace_item = snippets[0].workspace_item
-#     start_date, end_date = current_start_end_dates(request)
-#     layout_extra = snippet_group.layout()  # Basic extra's, x-min, title, ...
-
-#     # Add current position of slider, if available
-
-#     layout_extra.update(slider_layout_extra(request))
-
-#     return using_workspace_item.adapter.image(identifiers,
-#                                               start_date, end_date,
-#                                               width, height,
-#                                               layout_extra=layout_extra)
-
-
-# @never_cache
-# def session_workspace_extent(request, workspace_category='user'):
-#     """Returns extent for the workspace in json.
-#     """
-#     if 'workspaces' in request.session:
-#         workspace_id = request.session['workspaces'][workspace_category][0]
-#         workspace = get_object_or_404(Workspace, pk=workspace_id)
-#         return HttpResponse(json.dumps(workspace.extent()))
-#     else:
-#         return HttpResponse(json.dumps(''))
-
-
 def popup_json(found, popup_id=None, hide_add_snippet=False, request=None):
     """Return html with info on list of 'found' objects.
 
@@ -834,6 +779,8 @@ def group_collage_items(collage_items):
     The grouping is done automagically by adapter property "grouping
     hint", or adapter/adapter_layer_arguments by creating collage
     items with extra property "identifiers".
+
+    TODO: test
     """
     # for collage_item in collage_items:
     #     collage_item.identifiers = [collage_item.identifier, ]
@@ -841,6 +788,7 @@ def group_collage_items(collage_items):
     # Identifiers by grouping hint. Content is a list with collage
     # items.
     grouped_collage_items = {}
+    collage_item_group = {}  # For each collage_item_id: which grouping_hint?
 
     for collage_item in collage_items:
         grouping_hint = collage_item.grouping_hint
@@ -848,8 +796,9 @@ def group_collage_items(collage_items):
             grouped_collage_items[grouping_hint] = []
         grouped_collage_items[grouping_hint].append(
             collage_item)
+        collage_item_group[collage_item.id] = grouping_hint
 
-    return grouped_collage_items
+    return grouped_collage_items, collage_item_group
 
 
 # Updated for L3.
@@ -861,7 +810,7 @@ def popup_collage_json(collage_items, popup_id, request=None):
     html = []
     big_popup = True
 
-    grouped_collage_items = group_collage_items(collage_items)
+    grouped_collage_items, _ = group_collage_items(collage_items)
     for collage_items in grouped_collage_items.values():
         collage_item = collage_items[0]  # Each group always has items.
         identifiers = [collage_item.identifier for
@@ -1109,15 +1058,37 @@ class CollageDetailView(
     Shows "my collage" as big page.
     """
     template_name = 'lizard_map/collage_edit_detail.html'
+    hide_statistics = False
 
     def grouped_collage_items(self):
         """A grouped collage item is a collage item with property
         "identifiers": a list of identifiers """
-        collage_items = group_collage_items(
+        collage_items, _ = group_collage_items(
             self.collage_edit().collage_items.filter(visible=True))
 
         return collage_items
 
+    def get(self, request, *args, **kwargs):
+        self.hide_statistics = request.GET.get('hide_statistics', False)
+
+        return super(CollageDetailView, self).get(request, *args, **kwargs)
+
+
+class CollageStatisticsView(
+    ViewContextMixin, TemplateView):
+    """
+    Shows statistics for collage items.
+    """
+    template_name = 'lizard_map/box_statistics.html'
+    collage_items = None
+
+    def get(self, request, *args, **kwargs):
+        collage_item_ids = request.GET.getlist('collage_item_id')
+        self.collage_items = CollageEditItem.objects.filter(
+            id__in=collage_item_ids)
+
+        return super(CollageStatisticsView, self).get(request, *args, **kwargs)
+
 
 class CollageView(CollageMixin, ActionDialogView):
     """
@@ -1177,7 +1148,7 @@ class CollageAddView(CollageMixin, ActionDialogView):
         collage.collage_items.create(
             adapter_class=data['adapter_class'],
             adapter_layer_json=data['adapter_layer_json'],
-            name=data['name'],
+            name=data['name'][:80],
             identifier=parse_identifier_json(data['identifier']))
 
 
@@ -1394,6 +1365,8 @@ def save_map_as_image(request):
 
 
 def create_mapnik_image(request, data):
+    """TODO: remove copy-pasting.
+    """
     # Map settings
     mapnik_map = mapnik.Map(data['width'], data['height'])
     layers = data['layers']
@@ -1432,12 +1405,14 @@ def create_mapnik_image(request, data):
 def mapnik_image_to_stream(request, data, img):
     """
     Convert mapnik image object to bytes stream
+
+    TODO: remove hardcoding url
     """
     http_user_agent = request.META.get('HTTP_USER_AGENT', '')
     logger.debug("Converting image to rgba...")
 
     bbox = ",".join([str(x) for x in data['bbox']])
-    geoserver_img = urllib2.urlopen("http://geoserver.lizard.net/geoserver/"+
+    geoserver_img = urllib2.urlopen("http://10.100.130.132:8080/geoserver/"+
         "wms?LAYERS=nhi%3Awaterkaart&FORMAT=image%2Fpng&MAXRESOLUTION=364&SERVICE"+
         "=WMS&VERSION=1.1.1&REQUEST=GetMap&STYLES=&EXCEPTIONS=application%2Fvnd."+
         "ogc.se_inimage&SRS=EPSG%3A28992&BBOX="+ str(bbox) +
