@@ -9,7 +9,7 @@ from lizard_map.adapter import adapter_serialize
 from lizard_map.models import ICON_ORIGINALS
 from lizard_map.models import Color
 from lizard_map.models import Legend
-#from lizard_map.models import Workspace
+#from lizard_map.models import Workspace foo
 from lizard_map.symbol_manager import SymbolManager
 
 logger = logging.getLogger('lizard_map.workspace')
@@ -309,7 +309,10 @@ class WorkspaceItemAdapter(object):
 
         # Fetch name
         if identifiers:
-            location = self.location(**identifiers[0])
+            identifier_str = {}
+            for k, v in identifiers[0].items():
+                identifier_str[str(k)] = v
+            location = self.location(**identifier_str)
             title = location['name']
             if len(identifiers) > 1:
                 title += ' + ...'
@@ -323,24 +326,28 @@ class WorkspaceItemAdapter(object):
         # Makes it possible to create collage items from current
         # selected objects.
         collage_item_props = []
-        for identifier in identifiers:
-            location = self.location(**identifier)
-            collage_item_props.append(
-                {'name': location['name'],
-                 'adapter_class': self.workspace_mixin_item.adapter_class,
-                 'adapter_layer_json':
-                     self.workspace_mixin_item.adapter_layer_json,
-                 'identifier': adapter_serialize(identifier),
-                 'url': self.workspace_mixin_item.url(
-                        "lizard_map_adapter_values", [identifier, ],
-                        extra_kwargs={'output_type': 'csv'})})
+        # No export and selection for collages.
+        if not is_collage:
+            for identifier in identifiers:
+                identifier_str = {}
+                for k, v in identifier.items():
+                    identifier_str[str(k)] = v
+                location = self.location(**identifier_str)
+                collage_item_props.append(
+                    {'name': location['name'],
+                     'adapter_class': self.workspace_mixin_item.adapter_class,
+                     'adapter_layer_json':
+                         self.workspace_mixin_item.adapter_layer_json,
+                     'identifier': adapter_serialize(identifier),
+                     'url': self.workspace_mixin_item.url(
+                            "lizard_map_adapter_values", [identifier, ],
+                            extra_kwargs={'output_type': 'csv'})})
 
         render_kwargs = {
             'title': title,
             'img_url': img_url,
             'symbol_url': self.symbol_url(),
-            'collage_item_props': collage_item_props,
-            'is_collage': is_collage}
+            'collage_item_props': collage_item_props}
         if layout_options is not None:
             render_kwargs.update(layout_options)
 
@@ -371,7 +378,7 @@ class WorkspaceItemAdapter(object):
             # Fallback if no legend found (should not happen)
             logger.warn("Could not find legend for key '%s', "
                         "please configure the legend. "
-                        "Now using fallback (red).")
+                        "Now using fallback (red)." % legend_name)
             color = Color('ff0000')
             found_legend = Legend(descriptor="", min_color=color,
                                   max_color=color, too_low_color=color,
